@@ -9,7 +9,7 @@ function(net,rich="k", reshuffle="weights", NR=1000, nbins=30, seed=NULL, direct
     set.seed(as.integer(seed))
   # Check if network is directed
   if(is.null(directed)) 
-    directed <- (nrow(symmetrise(net)) != nrow(net))
+    directed <- (nrow(symmetrise_w(net)) != nrow(net))
   # Internal function: the non-normalised coefficient
   `phi` <- function(net){
     output <- cbind(x=xlevels,num=NaN,den=NaN,y=NaN)
